==> lcov-server-1.1.9.tgz: package/distributed/index.js <==
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var mongoose = require('mongoose');

mongoose.Promise = global.Promise;
mongoose.connect(process.env.MONGO_URL, { useMongoClient: true }, function (error) {
  if (error) {
    console.error(error.message); // eslint-disable-line
    process.exit(1);
  }
});

var express = require('express');
var Badge = require('openbadge');
var parse = require('git-url-parse');
var path = require('path');
var serveStatic = require('serve-static');
var compression = require('compression');
var bodyParser = require('body-parser');
var zlib = require('zlib');

zlib.level = zlib.Z_BEST_COMPRESSION;

var Coverage = require('./lib/coverage');

var port = process.env.PORT || 8080;
var asyncMiddleware = function asyncMiddleware(fn) {
  return function (req, res, next) {
    Promise.resolve(fn(req, res, next)).catch(next);
  };
};
var app = express();

app.use(bodyParser.json());
app.use(compression());
app.use(serveStatic(path.resolve(__dirname, 'dist'), {
  maxAge: '1d',
  etag: false
}));

app.post('/api/upload', asyncMiddleware(function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(req, res) {
    var _req$body, git, run_at, source_files, service_job_id, service_pull_request, service_name, results;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _req$body = req.body, git = _req$body.git, run_at = _req$body.run_at, source_files = _req$body.source_files, service_job_id = _req$body.service_job_id, service_pull_request = _req$body.service_pull_request, service_name = _req$body.service_name;

            // Make sure the remote url is set correctly

            git.remotes.url = parse(parse(git.remotes.url).toString("ssh")).toString("https");

            _context.prev = 2;
            _context.next = 5;
            return Coverage.save({
              source_files: source_files,
              git: git,
              run_at: run_at,
              service_job_id: service_job_id,
              service_pull_request: service_pull_request,
              service_name: service_name
            });

          case 5:
            results = _context.sent;

            res.send({ results: results });
            _context.next = 13;
            break;

          case 9:
            _context.prev = 9;
            _context.t0 = _context['catch'](2);

            res.status(500);
            res.send({ error: _context.t0 });

          case 13:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[2, 9]]);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}()));

app.get('/api/repos', asyncMiddleware(function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(req, res) {
    var repos;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return Coverage.repos();

          case 3:
            repos = _context2.sent;

            res.send(repos);
            _context2.next = 11;
            break;

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);

            res.status(500);
            res.send({ error: _context2.t0 });

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function (_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}()));

app.get('/api/repos/:service/:owner/', asyncMiddleware(function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(req, res) {
    var _req$params, service, owner, coverages;

    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _req$params = req.params, service = _req$params.service, owner = _req$params.owner;
            _context3.prev = 1;
            _context3.next = 4;
            return Coverage.repos(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/'));

          case 4:
            coverages = _context3.sent;

            res.send(coverages);
            _context3.next = 12;
            break;

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3['catch'](1);

            res.status(500);
            res.send({ error: _context3.t0 });

          case 12:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[1, 8]]);
  }));

  return function (_x5, _x6) {
    return _ref3.apply(this, arguments);
  };
}()));

app.get('/api/coverage/:service/:owner/:repo/', asyncMiddleware(function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(req, res) {
    var limit, _req$params2, service, owner, repo, coverages;

    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            limit = req.query.limit;
            _req$params2 = req.params, service = _req$params2.service, owner = _req$params2.owner, repo = _req$params2.repo;
            _context4.prev = 2;
            _context4.next = 5;
            return Coverage.get(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/' + repo), limit);

          case 5:
            coverages = _context4.sent;

            res.send(coverages);
            _context4.next = 13;
            break;

          case 9:
            _context4.prev = 9;
            _context4.t0 = _context4['catch'](2);

            res.status(500);
            res.send({ error: _context4.t0 });

          case 13:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[2, 9]]);
  }));

  return function (_x7, _x8) {
    return _ref4.apply(this, arguments);
  };
}()));

app.get('/badge/:service/:owner/:repo.svg', asyncMiddleware(function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(req, res) {
    var _req$params3, service, owner, repo, coverages, coverage, history, source_files, found, hit, percentage, color;

    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _req$params3 = req.params, service = _req$params3.service, owner = _req$params3.owner, repo = _req$params3.repo;
            _context5.prev = 1;
            _context5.next = 4;
            return Coverage.get(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/' + repo), 1);

          case 4:
            coverages = _context5.sent;
            coverage = coverages[0];
            history = coverage.history;
            source_files = history[0].source_files;
            found = 0;
            hit = 0;

            source_files.forEach(function (file) {
              var _file$lines = file.lines,
                  lines = _file$lines === undefined ? { hit: 0, found: 0 } : _file$lines,
                  _file$branches = file.branches,
                  branches = _file$branches === undefined ? { hit: 0, found: 0 } : _file$branches,
                  _file$functions = file.functions,
                  functions = _file$functions === undefined ? { hit: 0, found: 0 } : _file$functions;

              found += lines.found + branches.found + functions.found;
              hit += lines.hit + branches.hit + functions.hit;
            });
            percentage = parseInt(hit / found * 100);
            color = percentage >= 85 ? '#3DB712' : percentage <= 85 && percentage >= 70 ? '#caa300' : '#cc5338';


            Badge({ color: { right: color }, text: ['coverage', percentage + '%'] }, function (err, badge) {
              if (err) {
                throw new Error(err);
              }
              res.set('Content-Type', 'image/svg+xml; charset=utf-8');
              res.send(badge);
            });
            _context5.next = 19;
            break;

          case 16:
            _context5.prev = 16;
            _context5.t0 = _context5['catch'](1);

            Badge({ color: { right: "#b63b3b" }, text: ['coverage', 'not found'] }, function (err, badge) {
              if (err) {
                throw new Error(err);
              }
              res.set('Content-Type', 'image/svg+xml; charset=utf-8');
              res.send(badge);
            });

          case 19:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[1, 16]]);
  }));

  return function (_x9, _x10) {
    return _ref5.apply(this, arguments);
  };
}()));

app.get('*', function (req, res) {
  res.sendFile(path.resolve(__dirname, 'dist', 'index.html'));
});

app.listen(port, function () {
  console.log('lcov-server is listening on http://localhost:' + port); // eslint-disable-line
});

==> lcov-server-1.2.3.tgz: package/distributed/index.js <==
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var mongoose = require('mongoose');

mongoose.Promise = global.Promise;
mongoose.connect(process.env.MONGO_URL, { useMongoClient: true }, function (error) {
  if (error) {
    console.error(error.message); // eslint-disable-line
    process.exit(1);
  }
});

var express = require('express');
var Badge = require('openbadge');
var parse = require('git-url-parse');
var path = require('path');
var serveStatic = require('serve-static');
var compression = require('compression');
var bodyParser = require('body-parser');
var zlib = require('zlib');

zlib.level = zlib.Z_BEST_COMPRESSION;

var Coverage = require('./lib/coverage');

var port = process.env.PORT || 8080;
var asyncMiddleware = function asyncMiddleware(fn) {
  return function (req, res, next) {
    Promise.resolve(fn(req, res, next)).catch(next);
  };
};
var app = express();

app.use(bodyParser.json());
app.use(compression());
app.use(serveStatic(path.resolve(__dirname, 'dist'), {
  maxAge: '1d',
  etag: false
}));

app.post('/api/upload', asyncMiddleware(function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(req, res) {
    var _req$body, git, run_at, source_files, service_job_id, service_pull_request, service_name, results;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _req$body = req.body, git = _req$body.git, run_at = _req$body.run_at, source_files = _req$body.source_files, service_job_id = _req$body.service_job_id, service_pull_request = _req$body.service_pull_request, service_name = _req$body.service_name;

            // Make sure the remote url is set correctly

            git.remotes.url = parse(parse(git.remotes.url).toString("ssh")).toString("https");

            _context.prev = 2;
            _context.next = 5;
            return Coverage.save({
              source_files: source_files,
              git: git,
              run_at: run_at,
              service_job_id: service_job_id,
              service_pull_request: service_pull_request,
              service_name: service_name
            });

          case 5:
            results = _context.sent;

            res.send({ results: results });
            _context.next = 13;
            break;

          case 9:
            _context.prev = 9;
            _context.t0 = _context['catch'](2);

            res.status(500);
            res.send({ error: _context.t0 });

          case 13:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[2, 9]]);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}()));

app.get('/api/repos', asyncMiddleware(function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(req, res) {
    var repos;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return Coverage.repos();

          case 3:
            repos = _context2.sent;

            res.send(repos);
            _context2.next = 11;
            break;

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);

            res.status(500);
            res.send({ error: _context2.t0 });

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function (_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}()));

app.get('/api/feed/:page?', asyncMiddleware(function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(req, res) {
    var page, feed;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            page = req.params.page;
            _context3.prev = 1;
            _context3.next = 4;
            return Coverage.feed(page);

          case 4:
            feed = _context3.sent;

            res.send(feed);
            _context3.next = 12;
            break;

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3['catch'](1);

            res.status(500);
            res.send({ error: _context3.t0 });

          case 12:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[1, 8]]);
  }));

  return function (_x5, _x6) {
    return _ref3.apply(this, arguments);
  };
}()));

app.get('/api/repos/:service/:owner/', asyncMiddleware(function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(req, res) {
    var _req$params, service, owner, coverages;

    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _req$params = req.params, service = _req$params.service, owner = _req$params.owner;
            _context4.prev = 1;
            _context4.next = 4;
            return Coverage.repos(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/'));

          case 4:
            coverages = _context4.sent;

            res.send(coverages);
            _context4.next = 12;
            break;

          case 8:
            _context4.prev = 8;
            _context4.t0 = _context4['catch'](1);

            res.status(500);
            res.send({ error: _context4.t0 });

          case 12:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[1, 8]]);
  }));

  return function (_x7, _x8) {
    return _ref4.apply(this, arguments);
  };
}()));

app.get('/api/coverage/:service/:owner/:repo/', asyncMiddleware(function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(req, res) {
    var limit, _req$params2, service, owner, repo, coverages;

    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            limit = req.query.limit;
            _req$params2 = req.params, service = _req$params2.service, owner = _req$params2.owner, repo = _req$params2.repo;
            _context5.prev = 2;
            _context5.next = 5;
            return Coverage.get(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/' + repo), limit);

          case 5:
            coverages = _context5.sent;

            res.send(coverages);
            _context5.next = 13;
            break;

          case 9:
            _context5.prev = 9;
            _context5.t0 = _context5['catch'](2);

            res.status(500);
            res.send({ error: _context5.t0 });

          case 13:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[2, 9]]);
  }));

  return function (_x9, _x10) {
    return _ref5.apply(this, arguments);
  };
}()));

app.get('/badge/:service/:owner/:repo.svg', asyncMiddleware(function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(req, res) {
    var _req$params3, service, owner, repo, coverages, coverage, history, source_files, found, hit, percentage, color;

    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _req$params3 = req.params, service = _req$params3.service, owner = _req$params3.owner, repo = _req$params3.repo;
            _context6.prev = 1;
            _context6.next = 4;
            return Coverage.get(new RegExp(service.replace(/%2E/g, '.') + '.*/' + owner + '/' + repo), 1);

          case 4:
            coverages = _context6.sent;
            coverage = coverages[0];
            history = coverage.history;
            source_files = history[0].source_files;
            found = 0;
            hit = 0;

            source_files.forEach(function (file) {
              var _file$lines = file.lines,
                  lines = _file$lines === undefined ? { hit: 0, found: 0 } : _file$lines,
                  _file$branches = file.branches,
                  branches = _file$branches === undefined ? { hit: 0, found: 0 } : _file$branches,
                  _file$functions = file.functions,
                  functions = _file$functions === undefined ? { hit: 0, found: 0 } : _file$functions;

              found += lines.found + branches.found + functions.found;
              hit += lines.hit + branches.hit + functions.hit;
            });
            percentage = parseInt(hit / found * 100);
            color = percentage >= 85 ? '#3DB712' : percentage <= 85 && percentage >= 70 ? '#caa300' : '#cc5338';


            Badge({ color: { right: color }, text: ['coverage', percentage + '%'] }, function (err, badge) {
              if (err) {
                throw new Error(err);
              }
              res.set('Content-Type', 'image/svg+xml; charset=utf-8');
              res.send(badge);
            });
            _context6.next = 19;
            break;

          case 16:
            _context6.prev = 16;
            _context6.t0 = _context6['catch'](1);

            Badge({ color: { right: "#b63b3b" }, text: ['coverage', 'not found'] }, function (err, badge) {
              if (err) {
                throw new Error(err);
              }
              res.set('Content-Type', 'image/svg+xml; charset=utf-8');
              res.send(badge);
            });

          case 19:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[1, 16]]);
  }));

  return function (_x11, _x12) {
    return _ref6.apply(this, arguments);
  };
}()));

app.get('*', function (req, res) {
  res.sendFile(path.resolve(__dirname, 'dist', 'index.html'));
});

app.listen(port, function () {
  console.log('lcov-server is listening on http://localhost:' + port); // eslint-disable-line
});
